# Generated by Django 5.0.4 on 2024-05-13 15:33

from django.db import migrations
from wagtail.models import Site

from shared.blocks import PeopleOverviewBlock


def add_people_blocks(apps, schema_editor):
    # Get the page model
    DistrictPeoplePage = apps.get_model("district", "DistrictPeoplePage")
    DistrictPersonPage = apps.get_model("district", "DistrictPersonPage")
    DistrictHomePage = apps.get_model("district", "DistrictHomePage")

    for people_page in DistrictPeoplePage.objects.all():
        people_blocks = people_page.people.get_prep_value()

        person_boxes = []

        # Get the path of the current people_page
        people_page_path = people_page.path

        # Get DistrictHomePage ancestor
        home_page = DistrictHomePage.objects.filter(
            path__startswith=people_page_path[:-4], depth__lt=people_page.depth
        ).first()

        if not home_page:
            print(
                f"DistrictPeoplePage with id {people_page.id} has no DistrictHomePage ancestor."
            )
            continue

        # Find the site for the people_page
        site = Site.objects.filter(
            root_page__path__startswith=people_page.path[:4]
        ).first()
        people_page_url = f"{site.root_url}{people_page.url_path}"

        if not site:
            print(f"No site found for DistrictPeoplePage with id {people_page.id}.")
            continue

        for position, block in enumerate(people_blocks):
            title = block["value"]["title"]
            slug = block["value"]["slug"]

            people = []

            person_list_blocks = block["value"]["person_list"]

            for block in person_list_blocks:
                people.append(
                    DistrictPersonPage.objects.filter(id=block["value"]).first()
                )

            if "zastupitel" in title.lower():
                title = "Zastupitelé"
            elif (
                "předsednicto" in title.lower() or "předsedové" in title.lower()
            ) and (
                "kraj" not in title.lower()
                and "místní" not in title.lower()
                and "ms" not in title.lower()
                and "ks" not in title.lower()
            ):
                title = "Předsednictvo"
            elif "člen" in title.lower():
                title = "Členstvo"
            elif (
                "předsednicto" in title.lower() or "předsedové" in title.lower()
            ) and ("kraj" in title.lower() or "ks" in title.lower()):
                title = "Předsednictvo KS"
            elif (
                "předsednicto" in title.lower() or "předsedové" in title.lower()
            ) and ("místní" in title.lower() or "ms" in title.lower()):
                if "ks" in home_page.title.lower():
                    title = "Předsednictva MS"
                else:
                    title = "Předsednictvo MS"

            first_person_page = None

            for person in people:
                if not person.profile_image:
                    continue

                first_person_page = person
                break

            if first_person_page is not None:
                person_boxes.append(
                    {
                        "title": title,
                        "url": f"{people_page_url}?view={slug}-{position + 1}",
                        "first_person_page": first_person_page,
                    }
                )

        people_box_blocks = []

        for person in person_boxes:
            people_box_blocks.append(
                {
                    "title": person["title"],
                    "button_link": person["url"],
                    "button_text": "Zobrazit osoby",
                    "image": person["first_person_page"].profile_image.id,
                }
            )

        people_overview_block = PeopleOverviewBlock().to_python(
            {
                "title_line_1": (
                    "Lidé v krajském"
                    if "ks" in home_page.title.lower()
                    else (
                        "Lidé v místním"
                        if "ms" in home_page.title.lower()
                        else "Lidé v sdružení"
                    )
                ),
                "title_line_2": (
                    "sdružení"
                    if (
                        "ks" in home_page.title.lower()
                        or "ms" in home_page.title.lower()
                    )
                    else ""
                ),
                "description": "",
                "list": people_box_blocks[:4],
            }
        )

        if isinstance(home_page, DistrictHomePage):
            home_page.content.append(("people_block", people_overview_block))
            home_page.save()


class Migration(migrations.Migration):
    dependencies = [
        ("district", "0193_remove_districthomepage_show_pirati_cz_link_and_more"),
    ]

    operations = [
        migrations.RunPython(add_people_blocks),
    ]
